% File src/library/base/man/paste.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{paste}
\title{Concatenate Strings}
\concept{combine strings}
\usage{
paste (\dots, sep = " ", collapse = NULL)
paste0(\dots, collapse = NULL)
}
\alias{paste}
\alias{paste0}
\arguments{
  \item{\dots}{文字列に変換される一つ又はそれ以上の \R オブジェクト．}
  \item{sep}{項を分離する文字列．\code{\link{NA_character_}} は不可．}
  \item{collapse}{結果を分離するオプションの文字列．\code{\link{NA_character_}} は不可．}
}
\description{
  文字列に変換後ベクトルを連結する．
}
\details{
  \code{paste} はその引数を 
  \code{\link{as.character}}) を使って文字列に変換し，そしてそれらを
  (\code{sep} で与えられた文字列でそれらを分離し)連結する．
  もし引数がベクトルならば，それらは項毎に連結され一つの文字列を
  与える．ベクトル引数は必要に応じてリサイクルされ，
  長さゼロの引数は \code{""} にリサイクルされる．

  \code{paste()} は文字列欠損値 \code{\link{NA_character_}} を
  \code{"NA"} に変換するが，
  これは例えば二つのベクトルを結合するときは好ましくないかもしれず，
  例えば \code{paste("the value of p is ", p)} 中では
  非常に好ましいかもしれない．

  \code{paste0(\dots, collapse)} は
  \code{paste(\dots, sep = "", collapse)} と同値であるが，
  少し効率的である．

  もし \code{collapse} に対して値が提供されると，結果中の値は
  単一の文字列に連結され，要素は
  \code{collapse} の値で分離されている．
}
\value{
  連結された値のベクトル．これはもし全てのオブジェクトがそうであれば
  \code{collapse} が NULL で無い限り長さがゼロになる．
  \code{collapse} が NULL ならば単一の空文字列になる．

  もし結果の要素中のどれかが UTF-8 (そしてどれもが
  エンコーディング \code{"bytes"} と宣言されていなければ)
  (\code{\link{Encoding}}を見よ)ならばその要素は UTF-8 になる．
  さもなければ現在のエンコーディングで，その場合
  もし現在のロケールが Latin-1 か UTF-8 で少なくとも一つの対応入力
  (分離子を含む)が宣言されたエンコーディングを持ち全ての入力が
  ASCII か宣言されていれば，要素のエンコーディングが宣言される．

%  If any input into an element of the result is in UTF-8 (and none are
%  declared with encoding \code{"bytes"}, (see \code{\link{Encoding}}),
%  that element will be in UTF-8, otherwise in the current encoding in
%  which case the encoding of the element is declared if the current
%  locale is either Latin-1 or UTF-8, at least one of the corresponding
%  inputs (including separators) had a declared encoding and all inputs
%  were either ASCII or declared.

  もしある要素への入力がエンコーディング \code{"bytes"} と宣言されていれば，
  要素のどれもが翻訳されず，結果の要素はエンコーディング \code{"bytes"} を
  持つ．もし \code{collapse} が NULL でなければ，これはまた二番目の
  縮約フェイズにも適用されるが，幾つかの翻訳は最初のフェイズ中でオブジェクト
  を一緒に結合して行われるかもしれない．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{toString}} は典型的に \code{paste(*, collapse=", ")} を呼び出す．
  \code{\link{as.character}}, \code{\link{substr}}, \code{\link{nchar}},
  \code{\link{strsplit}} を用いた文字列操作；
  \code{\link{cat}} は連結しファイルに書き出す．
  そして C 風の文字列構成には \code{\link{sprintf}}．

  プロットの注釈中で \code{paste} を使う \sQuote{\link{plotmath}}．
}
\examples{
## 一つのベクトルを渡すと paste0 と paste は as.character のように動作する．
paste0(1:12)
paste(1:12)        # 同じ
as.character(1:12) # 同じ

## 複数のベクトルを paste0 に渡すとそれらはベクトル化されて連結される．
(nth <- paste0(1:12, c("st", "nd", "rd", rep("th", 9))))

## paste は同様に動作するが各入力を空白で分離する．
## リサイクル規則は各入力を最長の入力と同じ長さにすることを注意．
paste(month.abb, "is the", nth, "month of the year.")
paste(month.abb, letters)

## 分離記号は sep 引数で変更でき，複数の文字で良い．
paste(month.abb, "is the", nth, "month of the year.", sep = "_*_")

## 出力を単一の文字列に潰すには collapse 引数を渡す．
paste0(nth, collapse = ", ")

## 長さ1の入力には collapse 引数よりも sep 引数を使う
paste("1st", "2nd", "3rd", collapse = ", ") # 恐らく期待したものと異なる
paste("1st", "2nd", "3rd", sep = ", ")

## sep と collapse 引数を同時に使うことが出来る．
paste(month.abb, nth, sep = ": ", collapse = "; ")

## 長い文字列を処理するには paste() を strwrap() と併用すると役に立つ
(title <- paste(strwrap(
    "Stopping distance of cars (ft) vs. speed (mph) from Ezekiel (1930)",
    width = 30), collapse = "\n"))
plot(dist ~ speed, cars, main = title)
}
\keyword{character}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/paste.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{paste}
%\title{Concatenate Strings}
%\concept{combine strings}
%\usage{
%paste (\dots, sep = " ", collapse = NULL)
%paste0(\dots, collapse = NULL)
%}
%\alias{paste}
%\alias{paste0}
%\arguments{
%  \item{\dots}{one or more \R objects, to be converted to character vectors.}
%  \item{sep}{a character string to separate the terms.  Not
%    \code{\link{NA_character_}}.}
%  \item{collapse}{an optional character string to separate the results.  Not
%    \code{\link{NA_character_}}.}
%}
%\description{
%  Concatenate vectors after converting to character.
%}
%\details{
%  \code{paste} converts its arguments (\emph{via}
%  \code{\link{as.character}}) to character strings, and concatenates
%  them (separating them by the string given by \code{sep}).  If the
%  arguments are vectors, they are concatenated term-by-term to give a
%  character vector result.  Vector arguments are recycled as needed,
%  with zero-length arguments being recycled to \code{""}.
%
%  Note that \code{paste()} coerces \code{\link{NA_character_}}, the
%  character missing value, to \code{"NA"} which may seem
%  undesirable, e.g., when pasting two character vectors, or very
%  desirable, e.g.\sspace{}in \code{paste("the value of p is ", p)}.
%
%  \code{paste0(\dots, collapse)} is equivalent to
%  \code{paste(\dots, sep = "", collapse)}, slightly more efficiently.
%
%  If a value is specified for \code{collapse}, the values in the result
%  are then concatenated into a single string, with the elements being
%  separated by the value of \code{collapse}.
%}
%\value{
%  A character vector of the concatenated values.  This will be of length
%  zero if all the objects are, unless \code{collapse} is non-NULL in
%  which case it is a single empty string.
%
%  If any input into an element of the result is in UTF-8 (and none are
%  declared with encoding \code{"bytes"}, (see \code{\link{Encoding}}),
%  that element will be in UTF-8, otherwise in the current encoding in
%  which case the encoding of the element is declared if the current
%  locale is either Latin-1 or UTF-8, at least one of the corresponding
%  inputs (including separators) had a declared encoding and all inputs
%  were either ASCII or declared.
%
%  If an input into an element is declared with encoding \code{"bytes"},
%  no translation will be done of any of the elements and the resulting
%  element will have encoding \code{"bytes"}.  If \code{collapse} is
%  non-NULL, this applies also to the second, collapsing, phase, but some
%  translation may have been done in pasting object together in the first
%  phase.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{toString}} typically calls \code{paste(*, collapse=", ")}.
%  String manipulation with
%  \code{\link{as.character}}, \code{\link{substr}}, \code{\link{nchar}},
%  \code{\link{strsplit}}; further, \code{\link{cat}} which concatenates and
%  writes to a file, and \code{\link{sprintf}} for C like string
%  construction.
%
%  \sQuote{\link{plotmath}} for the use of \code{paste} in plot annotation.
%}
%\examples{
%## When passing a single vector, paste0 and paste work like as.character.
%paste0(1:12)
%paste(1:12)        # same
%as.character(1:12) # same
%
%## If you pass several vectors to paste0, they are concatenated in a
%## vectorized way.
%(nth <- paste0(1:12, c("st", "nd", "rd", rep("th", 9))))
%
%## paste works the same, but separates each input with a space.
%## Notice that the recycling rules make every input as long as the longest input.
%paste(month.abb, "is the", nth, "month of the year.")
%paste(month.abb, letters)
%
%## You can change the separator by passing a sep argument
%## which can be multiple characters.
%paste(month.abb, "is the", nth, "month of the year.", sep = "_*_")
%
%## To collapse the output into a single string, pass a collapse argument.
%paste0(nth, collapse = ", ")
%
%## For inputs of length 1, use the sep argument rather than collapse
%paste("1st", "2nd", "3rd", collapse = ", ") # probably not what you wanted
%paste("1st", "2nd", "3rd", sep = ", ")
%
%## You can combine the sep and collapse arguments together.
%paste(month.abb, nth, sep = ": ", collapse = "; ")
%
%## Using paste() in combination with strwrap() can be useful
%## for dealing with long strings.
%(title <- paste(strwrap(
%    "Stopping distance of cars (ft) vs. speed (mph) from Ezekiel (1930)",
%    width = 30), collapse = "\n"))
%plot(dist ~ speed, cars, main = title)
%}
%\keyword{character}
%
\encoding{UTF8}
