% File src/library/graphics/man/axTicks.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{axTicks}
\alias{axTicks}
\title{Compute Axis Tickmark Locations}
\description{
  \R が内部的に行うのと同じ仕方で見栄えの良いチックマーク位置を計算する．
  これは\bold{対数}座標が使われている時だけ自明でない．
  既定では \code{\link{axis}(side)} が使う \code{at} 位置を返す．
}
\usage{
axTicks(side, axp = NULL, usr = NULL, log = NULL, nintLog = NULL)
}
\arguments{
  \item{side}{\code{\link{axis}} に対するような 1:4 中の整数．}
  \item{axp}{長さ 3 の数値ベクトル．既定では
    \code{side} 引数に依存して \code{\link{par}("xaxp")} か
    \code{\link{par}("yaxp")}(もし \code{side} が 1 か 3 ならば
    \code{par("xaxp")} で，もし \code{side} が 2 か 4 ならば \code{par("yaxp")})．}
  \item{usr}{ユーザ座標の限界を与える長さ 2 の数値ベクトル．
    既定では \code{\link{par}("usr")} の関連する部分
    (\code{side} が (1,3) か (2,4) 中ならそれぞれ \code{par("usr")[1:2]}
    または \code{par("usr")[3:4]}．}
  \item{log}{対数軸が使われているかどうかを指示する論理値；
    既定では \code{side} に依存して \code{\link{par}("xlog")} か
    \code{\link{par}("ylog")}．}
  \item{nintLog}{(\code{log} が真の時だけ使われる)：近似的なチック区間数
    (の下限)；既定では \code{\link{par}("lab")[j]} で，ここで \code{j}
    は \code{side} に依存して 1 か 2．もし初期(2.14.x 以前)の \R バージョン
    と同じ挙動が必要ならこれを \code{Inf} にする．}
}
\details{
  \code{axp}, \code{usr} そして \code{log} 引数はそれらの既定値
  (\code{par(..)} の結果)と一貫性が無ければならない．
  もし三つ全てを指定(非 NULL で)すれば，グラフィックス環境は全く
  使われない．\code{axp} の意味は \code{log} が \code{TRUE} の
  時は相当異なることを注意しよう；
  \code{\link{par}(xaxp = .)} に対するドキュメントを参照．

  \code{axTicks()} は \file{..../src/main/plot.c} 中の C 関数
  \code{CreateAtVector()} へのインタフェイスとして使える．これは
  \code{at} 引数が指定されないと \code{\link{axis}(side, *)} により
  呼び出される．
  微妙なケース \code{log = TRUE} は．
  後方互換性のために存在する \code{nintLog = Inf} でなければ，今や
  \code{\link{axisTicks}} (パッケージ \pkg{grDevices} 中)を使う．
}
\value{
  軸チックマークを置くことが出来る座標値の数値ベクトル．
  既定では，最初の引数だけが指定された時は，これらの値は
  \code{\link{axis}(side)} を使うもしくは使われた時の
  それと同じになるべきである．
  \code{usr} が減少順ならば値は減少順(\dQuote{逆軸}ケース)．
}
\seealso{\code{\link{axis}}, \code{\link{par}}.  \code{\link{pretty}}
  は同じアルゴリズム(しかしグラフィックス環境とは独立に)を使い，
  より多くのオプションを持つ．しかしながらこれは
  \code{log = TRUE} に対しては利用できない．

  \code{\link[grDevices]{axisTicks}()} (パッケージ \pkg{grDevices}).
}
\examples{
 plot(1:7, 10*21:27)
 axTicks(1)
 axTicks(2)
 stopifnot(identical(axTicks(1), axTicks(3)),
           identical(axTicks(2), axTicks(4)))

## axTicks() と axis() がどの様に対応するかを示す：
op <- par(mfrow = c(3, 1))
for(x in 9999 * c(1, 2, 8)) {
    plot(x, 9, log = "x")
    cat(formatC(par("xaxp"), width = 5),";", T <- axTicks(1),"\n")
    rug(T, col =  adjustcolor("red", 0.5), lwd = 4)
}
par(op)

x <- 9.9*10^(-3:10)
plot(x, 1:14, log = "x")
axTicks(1) # 長さは 5，R <= 2.13.x では次を与えた
axTicks(1, nintLog = Inf) # かなり多い

## 既存のプロットへの参照なしに axTicks() を使う例
## (R の軸範囲等の設定の内部手続きをコピー)，
## axp, usr, log, nintLog 全てを補う必要がある
## 標準対数 y 軸ラベル
ylims <- c(0.2, 88)
get_axp <- function(x) 10^c(ceiling(x[1]), floor(x[2]))
## par("yaxs") == "i" を模倣
usr.i <- log10(ylims)
(aT.i <- axTicks(side = 2, usr = usr.i,
                 axp = c(get_axp(usr.i), n = 3), log = TRUE, nintLog = 5))
## (既定の) par("yaxs") == "r" を模倣
usr.r <- extendrange(r = log10(ylims), f = 0.04)
(aT.r <- axTicks(side = 2, usr = usr.r,
                 axp = c(get_axp(usr.r), 3), log = TRUE, nintLog = 5))

## 上手くいっていることを確認：
plot(0:1, ylims, log = "y", yaxs = "i")
stopifnot(all.equal(aT.i, axTicks(side = 2)))

plot(0:1, ylims, log = "y", yaxs = "r")
stopifnot(all.equal(aT.r, axTicks(side = 2)))
}
\keyword{dplot}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/axTicks.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{axTicks}
%\alias{axTicks}
%\title{Compute Axis Tickmark Locations}
%\description{
%  Compute pretty tickmark locations, the same way as \R does internally.
%  This is only non-trivial when \bold{log} coordinates are active.
%  By default, gives the \code{at} values which
%  \code{\link{axis}(side)} would use.
%}
%\usage{
%axTicks(side, axp = NULL, usr = NULL, log = NULL, nintLog = NULL)
%}
%\arguments{
%  \item{side}{integer in 1:4, as for \code{\link{axis}}.}
%  \item{axp}{numeric vector of length three, defaulting to
%    \code{\link{par}("xaxp")} or \code{\link{par}("yaxp")}
%    depending on the \code{side} argument (\code{par("xaxp")}
%    if \code{side} is 1 or 3, \code{par("yaxp")} if side is 2 or 4).}
%  \item{usr}{numeric vector of length two giving user coordinate
%    limits, defaulting to the relevant portion of
%    \code{\link{par}("usr")} (\code{par("usr")[1:2]} or
%    \code{par("usr")[3:4]} for \code{side} in (1,3) or (2,4)
%    respectively).}
%  \item{log}{logical indicating if log coordinates are active; defaults
%    to \code{\link{par}("xlog")} or \code{\link{par}("ylog")}
%    depending on \code{side}.}
%  \item{nintLog}{(only used when \code{log} is true): approximate (lower
%    bound for the) number of tick intervals; defaults to
%    \code{\link{par}("lab")[j]} where \code{j} is 1 or 2 depending on
%    \code{side}.  Set this to \code{Inf} if you want the same behavior
%    as in earlier \R versions (than 2.14.x).}
%}
%\details{
%  The \code{axp}, \code{usr}, and \code{log} arguments must be consistent
%  as their default values (the \code{par(..)} results) are.  If you
%  specify all three (as non-NULL), the graphics environment is not used
%  at all.  Note that the meaning of \code{axp} differs significantly
%  when \code{log} is \code{TRUE}; see the documentation on
%  \code{\link{par}(xaxp = .)}.
%
%  \code{axTicks()} can be used an \R interface to the C function
%  \code{CreateAtVector()} in \file{..../src/main/plot.c}
%  which is called by \code{\link{axis}(side, *)} when no argument
%  \code{at} is specified.
%  The delicate case, \code{log = TRUE}, now makes use of
%  \code{\link{axisTicks}} (in package \pkg{grDevices}) unless
%  \code{nintLog = Inf} which exists for back compatibility.
%}
%\value{
%  numeric vector of coordinate values at which axis tickmarks can be
%  drawn.  By default, when only the first argument is specified,
%  these values should be identical to those that
%  \code{\link{axis}(side)} would use or has used.  Note that the values
%  are decreasing when \code{usr} is (\dQuote{reverse axis} case).
%}
%\seealso{\code{\link{axis}}, \code{\link{par}}.  \code{\link{pretty}}
%  uses the same algorithm (but independently of the graphics
%  environment) and has more options.  However it is not available for
%  \code{log = TRUE.}
%
%  \code{\link[grDevices]{axisTicks}()} (package \pkg{grDevices}).
%}
%\examples{
% plot(1:7, 10*21:27)
% axTicks(1)
% axTicks(2)
% stopifnot(identical(axTicks(1), axTicks(3)),
%           identical(axTicks(2), axTicks(4)))
%
%## Show how axTicks() and axis() correspond :
%op <- par(mfrow = c(3, 1))
%for(x in 9999 * c(1, 2, 8)) {
%    plot(x, 9, log = "x")
%    cat(formatC(par("xaxp"), width = 5),";", T <- axTicks(1),"\n")
%    rug(T, col =  adjustcolor("red", 0.5), lwd = 4)
%}
%par(op)
%
%x <- 9.9*10^(-3:10)
%plot(x, 1:14, log = "x")
%axTicks(1) # now length 5, in R <= 2.13.x gave the following
%axTicks(1, nintLog = Inf) # rather too many
%
%## An example using axTicks() without reference to an existing plot
%## (copying R's internal procedures for setting axis ranges etc.),
%## You do need to supply _all_ of axp, usr, log, nintLog
%## standard logarithmic y axis labels
%ylims <- c(0.2, 88)
%get_axp <- function(x) 10^c(ceiling(x[1]), floor(x[2]))
%## mimic par("yaxs") == "i"
%usr.i <- log10(ylims)
%(aT.i <- axTicks(side = 2, usr = usr.i,
%                 axp = c(get_axp(usr.i), n = 3), log = TRUE, nintLog = 5))
%## mimic (default) par("yaxs") == "r"
%usr.r <- extendrange(r = log10(ylims), f = 0.04)
%(aT.r <- axTicks(side = 2, usr = usr.r,
%                 axp = c(get_axp(usr.r), 3), log = TRUE, nintLog = 5))
%
%## Prove that we got it right :
%plot(0:1, ylims, log = "y", yaxs = "i")
%stopifnot(all.equal(aT.i, axTicks(side = 2)))
%
%plot(0:1, ylims, log = "y", yaxs = "r")
%stopifnot(all.equal(aT.r, axTicks(side = 2)))
%}
%\keyword{dplot}
%
%
\encoding{UTF8}
