% File src/library/stats/man/runmed.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{runmed}
\title{Running Medians -- Robust Scatter Plot Smoothing}
\alias{runmed}%@%\alias{ランニング・メディアン}

\description{
  奇数スパンのランニング・メディアンを計算する．
  これは考えられる限り\sQuote{最も頑健}な散布図平滑化である．
  効率性(と歴史的経緯)から，同じ結果を与える二つの異なったアルゴリズムを使うことが出来る．
}
\usage{
runmed(x, k, endrule = c("median", "keep", "constant"),
       algorithm = NULL, print.level = 0)
}
\arguments{
  \item{x}{数値ベクトル，平滑化される\sQuote{従属}変数．}
  \item{k}{メディアンウィンドの整数幅；奇数でなければならない．
    Turlach は既定値
    \code{k <- 1 + 2 * min((n-1)\%/\% 2, ceiling(0.1*n))} を持つ．
    孤立外れ値を消し去る\sQuote{最少}頑健平滑化には \code{k = 3}
    を使う．}
  \item{endrule}{最初と最後の(データの)値をどのように処理するかを指示する
    文字列．短縮化出来る．可能な値は：
    \describe{
      \item{\code{"keep"}}{両端の
	\eqn{k_2}{k2} 個の値を残す，ここで
	\eqn{k_2}{k2} はバンド幅の半分
        \code{k2 = k \%/\% 2}，つまり
	\eqn{j \in \{1,\ldots,k_2;
          n-k_2+1,\ldots,n\}}{j = 1, \dots, k2 and (n-k2+1), \dots, n}
	  に対して \code{y[j] = x[j]}．}
      \item{\code{"constant"}}{
        滑らかな\emph{constant}の端にするため
	\code{median(y[1:k2])} を最初にコピーし，最後も同様にする．}
      \item{\code{"median"}}{既定，
        引き続くより小さなバンド幅を使い端を平滑化するが，
        最初と最後の値に対しては
	Tukey の頑健端点規則を使う，
	\code{\link{smoothEnds}} を見よ．}
    }
  }
  \item{algorithm}{
    文字列(部分的に \code{"Turlach"} か
    \code{"Stuetzle"} にマッチする)又は既定では \code{NULL} で，
    どのアルゴリズムを適用するかを指示する．
    既定の選択は \code{n = length(x)} と
    \code{k} に依存し，大きめの問題には \code{"Turlach"} が使われる．}
  \item{print.level}{整数，
    アルゴリズムの饒舌度を指示する；
    普通のユーザは滅多に変更すべきではない．}
}
\value{
  \code{x} と同じ長さの平滑化ベクトルで，
  (\sQuote{奇数化された}) \code{k} を含む属性
  \code{k} を含む．
  }
\details{
  端点を別にすれば，結果
  Apart from the end values, the result
  \code{y = runmed(x, k)} は単に
  \code{y[j] = median(x[(j-k2):(j+k2)])} (\code{k = 2*k2+1}) で，
  非常に効率的に計算されている．

  二つのアルゴリズムは内部的には全く異なる：
  \describe{
    \item{\code{"Turlach"}}{は Berwin Turlach により実装された
      \enc{Härdle}{Haerdle}--Steiger
      アルゴリズムである(参考文献を見よ)．
      ツリーアルゴリズムが用いられ，効率性
      \eqn{O(n \log k)}{O(n * log(k))} を保証する，ここで
      \code{n = length(x)} で漸近的に最適である．}
    \item{\code{"Stuetzle"}}{
      (古い) Stuetzle--Friedman の移植で，平滑化ウィンドに
      一つの観測値が入り一つが外れる時メディアンの\emph{更新}を行う．
      この効率性は \eqn{O(n \times k)}{O(n * k)} であり漸近的により遅いが，
      小さな \eqn{k} や \eqn{n} に対してはかなり速い．}
  }

  現在ロングベクトルは
  \code{algorithm = "Steutzle"} に対してだけサポートされている．
}
\references{
  \enc{Härdle}{Haerdle}, W. and Steiger, W. (1995)
  [Algorithm AS 296] Optimal median smoothing,
  \emph{Applied Statistics} \bold{44}, 258--264.

  Jerome H. Friedman and Werner Stuetzle (1982)
  \emph{Smoothing of Scatterplots};
  Report, Dep. Statistics, Stanford U., Project Orion 003.

  Martin Maechler (2003)
  Fast Running Medians: Finite Sample and Asymptotic Optimality;
  working paper available from the author.
}
\author{Martin Maechler \email{maechler@stat.math.ethz.ch}，
  Werner Stuetzle の Fortran コードと
  Berwin Turlach の S-PLUS と C コードに依る．}
\seealso{
  \code{\link{smoothEnds}} は Tukey の端点規則を実装し，
  既定で \code{runmed(*, endrule = "median")} から呼び出される．
  \code{\link{smooth}} はその複合平滑化に 3 のランニング・メディアン
  を使う．
}
\examples{
require(graphics)

utils::example(nhtemp)
myNHT <- as.vector(nhtemp)
myNHT[20] <- 2 * nhtemp[20]
plot(myNHT, type = "b", ylim = c(48, 60), main = "Running Medians Example")
lines(runmed(myNHT, 7), col = "red")

## 特殊：一つの x に対して複数の y 値
plot(cars, main = "'cars' data and runmed(dist, 3)")
lines(cars, col = "light gray", type = "c")
with(cars, lines(speed, runmed(dist, k = 3), col = 2))
%% FIXME: Show how to do it properly ! tapply(*, unique(.), median)

## 少数の外れ値を持つ良い二次関数
y <- ys <- (-20:20)^2
y [c(1,10,21,41)] <- c(150, 30, 400, 450)
all(y == runmed(y, 1)) # 1-近傍 <==> 補間
plot(y) ## lines(y, lwd = .1, col = "light gray")
lines(lowess(seq(y), y, f = 0.3), col = "brown")
lines(runmed(y, 7), lwd = 2, col = "blue")
lines(runmed(y, 11), lwd = 2, col = "red")

## Lowess は頑健でない
y <- ys ; y[21] <- 6666 ; x <- seq(y)
col <- c("black", "brown","blue")
plot(y, col = col[1])
lines(lowess(x, y, f = 0.3), col = col[2])
%% predict(loess(y ~ x, span = 0.3, degree=1, family = "symmetric"))
%% gives 6-line warning but does NOT break down
lines(runmed(y, 7),      lwd = 2, col = col[3])
legend(length(y),max(y), c("data", "lowess(y, f = 0.3)", "runmed(y, 7)"),
       xjust = 1, col = col, lty = c(0, 1, 1), pch = c(1,NA,NA))
}
\keyword{smooth}
\keyword{robust}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/runmed.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{runmed}
%\title{Running Medians -- Robust Scatter Plot Smoothing}
%\alias{runmed}
%
%\description{
%  Compute running medians of odd span.  This is the \sQuote{most robust}
%  scatter plot smoothing possible.  For efficiency (and historical
%  reason), you can use one of two different algorithms giving identical
%  results.
%}
%\usage{
%runmed(x, k, endrule = c("median", "keep", "constant"),
%       algorithm = NULL, print.level = 0)
%}
%\arguments{
%  \item{x}{numeric vector, the \sQuote{dependent} variable to be
%    smoothed.}
%  \item{k}{integer width of median window; must be odd.  Turlach had a
%    default of \code{k <- 1 + 2 * min((n-1)\%/\% 2, ceiling(0.1*n))}.
%    Use \code{k = 3} for \sQuote{minimal} robust smoothing eliminating
%    isolated outliers.}
%  \item{endrule}{character string indicating how the values at the
%    beginning and the end (of the data) should be treated.
%    Can be abbreviated.  Possible values are:
%    \describe{
%      \item{\code{"keep"}}{keeps the first and last \eqn{k_2}{k2} values
%        at both ends, where \eqn{k_2}{k2} is the half-bandwidth
%        \code{k2 = k \%/\% 2},
%        i.e., \code{y[j] = x[j]} for \eqn{j \in \{1,\ldots,k_2;
%          n-k_2+1,\ldots,n\}}{j = 1, \dots, k2 and (n-k2+1), \dots, n};}
%      \item{\code{"constant"}}{copies \code{median(y[1:k2])} to the first
%        values and analogously for the last ones making the smoothed ends
%        \emph{constant};}
%      \item{\code{"median"}}{the default, smooths the ends by using
%        symmetrical medians of subsequently smaller bandwidth, but for
%        the very first and last value where Tukey's robust end-point
%        rule is applied, see \code{\link{smoothEnds}}.}
%    }
%  }
%  \item{algorithm}{character string (partially matching \code{"Turlach"} or
%    \code{"Stuetzle"}) or the default \code{NULL}, specifying which algorithm
%    should be applied.  The default choice depends on \code{n = length(x)}
%    and \code{k} where \code{"Turlach"} will be used for larger problems.}
%  \item{print.level}{integer, indicating verboseness of algorithm;
%    should rarely be changed by average users.}
%}
%\value{vector of smoothed values of the same length as \code{x} with an
%  \code{\link{attr}}ibute \code{k} containing (the \sQuote{oddified})
%  \code{k}.
%}
%\details{
%  Apart from the end values, the result \code{y = runmed(x, k)} simply has
%  \code{y[j] = median(x[(j-k2):(j+k2)])} (\code{k = 2*k2+1}), computed very
%  efficiently.
%
%  The two algorithms are internally entirely different:
%  \describe{
%    \item{\code{"Turlach"}}{is the \enc{Härdle}{Haerdle}--Steiger
%      algorithm (see Ref.) as implemented by Berwin Turlach.
%      A tree algorithm is used, ensuring performance \eqn{O(n \log
%        k)}{O(n * log(k))} where \code{n = length(x)} which is
%      asymptotically optimal.}
%    \item{\code{"Stuetzle"}}{is the (older) Stuetzle--Friedman implementation
%      which makes use of median \emph{updating} when one observation
%      enters and one leaves the smoothing window.  While this performs as
%      \eqn{O(n \times k)}{O(n * k)} which is slower asymptotically, it is
%      considerably faster for small \eqn{k} or \eqn{n}.}
%  }
%
%  Currently long vectors are only supported for \code{algorithm = "Steutzle"}.
%}
%\references{
%  \enc{Härdle}{Haerdle}, W. and Steiger, W. (1995)
%  [Algorithm AS 296] Optimal median smoothing,
%  \emph{Applied Statistics} \bold{44}, 258--264.
%
%  Jerome H. Friedman and Werner Stuetzle (1982)
%  \emph{Smoothing of Scatterplots};
%  Report, Dep. Statistics, Stanford U., Project Orion 003.
%
%  Martin Maechler (2003)
%  Fast Running Medians: Finite Sample and Asymptotic Optimality;
%  working paper available from the author.
%}
%\author{Martin Maechler \email{maechler@stat.math.ethz.ch},
%  based on Fortran code from Werner Stuetzle and S-PLUS and C code from
%  Berwin Turlach.
%}
%\seealso{
%  \code{\link{smoothEnds}} which implements Tukey's end point rule and
%  is called by default from \code{runmed(*, endrule = "median")}.
%  \code{\link{smooth}} uses running
%  medians of 3 for its compound smoothers.
%}
%\examples{
%require(graphics)
%
%utils::example(nhtemp)
%myNHT <- as.vector(nhtemp)
%myNHT[20] <- 2 * nhtemp[20]
%plot(myNHT, type = "b", ylim = c(48, 60), main = "Running Medians Example")
%lines(runmed(myNHT, 7), col = "red")
%
%## special: multiple y values for one x
%plot(cars, main = "'cars' data and runmed(dist, 3)")
%lines(cars, col = "light gray", type = "c")
%with(cars, lines(speed, runmed(dist, k = 3), col = 2))
%%% FIXME: Show how to do it properly ! tapply(*, unique(.), median)
%
%## nice quadratic with a few outliers
%y <- ys <- (-20:20)^2
%y [c(1,10,21,41)] <- c(150, 30, 400, 450)
%all(y == runmed(y, 1)) # 1-neighbourhood <==> interpolation
%plot(y) ## lines(y, lwd = .1, col = "light gray")
%lines(lowess(seq(y), y, f = 0.3), col = "brown")
%lines(runmed(y, 7), lwd = 2, col = "blue")
%lines(runmed(y, 11), lwd = 2, col = "red")
%
%## Lowess is not robust
%y <- ys ; y[21] <- 6666 ; x <- seq(y)
%col <- c("black", "brown","blue")
%plot(y, col = col[1])
%lines(lowess(x, y, f = 0.3), col = col[2])
%%% predict(loess(y ~ x, span = 0.3, degree=1, family = "symmetric"))
%%% gives 6-line warning but does NOT break down
%lines(runmed(y, 7),      lwd = 2, col = col[3])
%legend(length(y),max(y), c("data", "lowess(y, f = 0.3)", "runmed(y, 7)"),
%       xjust = 1, col = col, lty = c(0, 1, 1), pch = c(1,NA,NA))
%}
%\keyword{smooth}
%\keyword{robust}
%
%\encoding{UTF-8}
%
